#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "about.h"
#include "opzioni.h"

#include <QtCore/QCoreApplication>
#include <QProcess>

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent), ui(new Ui::MainWindow)
{
    ui->setupUi(this);
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::setOrientation(ScreenOrientation orientation)
{
#if defined(Q_OS_SYMBIAN)
    // If the version of Qt on the device is < 4.7.2, that attribute won't work
    if (orientation != ScreenOrientationAuto) {
        const QStringList v = QString::fromAscii(qVersion()).split(QLatin1Char('.'));
        if (v.count() == 3 && (v.at(0).toInt() << 16 | v.at(1).toInt() << 8 | v.at(2).toInt()) < 0x040702) {
            qWarning("Screen orientation locking only supported with Qt 4.7.2 and above");
            return;
        }
    }
#endif // Q_OS_SYMBIAN

    Qt::WidgetAttribute attribute;
    switch (orientation) {
#if QT_VERSION < 0x040702
    // Qt < 4.7.2 does not yet have the Qt::WA_*Orientation attributes
    case ScreenOrientationLockPortrait:
        attribute = static_cast<Qt::WidgetAttribute>(128);
        break;
    case ScreenOrientationLockLandscape:
        attribute = static_cast<Qt::WidgetAttribute>(129);
        break;
    default:
    case ScreenOrientationAuto:
        attribute = static_cast<Qt::WidgetAttribute>(130);
        break;
#else // QT_VERSION < 0x040702
    case ScreenOrientationLockPortrait:
        attribute = Qt::WA_LockPortraitOrientation;
        break;
    case ScreenOrientationLockLandscape:
        attribute = Qt::WA_LockLandscapeOrientation;
        break;
    default:
    case ScreenOrientationAuto:
        attribute = Qt::WA_AutoOrientation;
        break;
#endif // QT_VERSION < 0x040702
    };
    setAttribute(attribute, true);
}

void MainWindow::showExpanded()
{
#if defined(Q_OS_SYMBIAN) || defined(Q_WS_SIMULATOR)
    showFullScreen();
#elif defined(Q_WS_MAEMO_5)
    showMaximized();
#else
    show();
#endif
}

void MainWindow::on_capital_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/capital.sh");
    process.waitForFinished();
}

void MainWindow::on_cielo_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/cielo.sh");
    process.waitForFinished();
}

void MainWindow::on_ditv_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/ditv.sh");
    process.waitForFinished();
}

void MainWindow::on_kataweb_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/kataweb.sh");
    process.waitForFinished();
}

void MainWindow::on_rtv_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/rtv38.sh");
    process.waitForFinished();
}

void MainWindow::on_telecupole_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/cupole.sh");
    process.waitForFinished();
}

void MainWindow::on_browserfb_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/browserfb.sh");
    process.waitForFinished();
}

void MainWindow::on_browsertw_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/browsertw.sh");
    process.waitForFinished();
}

void MainWindow::on_actionContattami_triggered()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/contattami.sh");
    process.waitForFinished();
}

void MainWindow::on_actionYoutube_triggered()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/youtube.sh");
    process.waitForFinished();
}

void MainWindow::on_pushButton_22_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d1.sh");
    process.waitForFinished();
}

void MainWindow::on_stream1_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p1.sh");
    process.waitForFinished();
}

void MainWindow::on_down2_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d2.sh");
    process.waitForFinished();
}

void MainWindow::on_stream2_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p2.sh");
    process.waitForFinished();
}

void MainWindow::on_down3_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d3.sh");
    process.waitForFinished();
}

void MainWindow::on_stream3_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p3.sh");
    process.waitForFinished();
}

void MainWindow::on_down4_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d4.sh");
    process.waitForFinished();
}

void MainWindow::on_stream4_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p4.sh");
    process.waitForFinished();
}

void MainWindow::on_down5_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d5.sh");
    process.waitForFinished();
}

void MainWindow::on_stream5_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p5.sh");
    process.waitForFinished();
}

void MainWindow::on_down6_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d6.sh");
    process.waitForFinished();
}

void MainWindow::on_stream6_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p6.sh");
    process.waitForFinished();
}

void MainWindow::on_down7_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d7.sh");
    process.waitForFinished();
}

void MainWindow::on_stream7_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p7.sh");
    process.waitForFinished();
}

void MainWindow::on_down8_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d8.sh");
    process.waitForFinished();
}

void MainWindow::on_stream8_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p8.sh");
    process.waitForFinished();
}

void MainWindow::on_down9_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d9.sh");
    process.waitForFinished();
}

void MainWindow::on_stream9_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p9.sh");
    process.waitForFinished();
}

void MainWindow::on_down10_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d10.sh");
    process.waitForFinished();
}

void MainWindow::on_stream10_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p10.sh");
    process.waitForFinished();
}

void MainWindow::on_down11_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d11.sh");
    process.waitForFinished();
}

void MainWindow::on_stream11_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p11.sh");
    process.waitForFinished();
}

void MainWindow::on_down12_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d12.sh");
    process.waitForFinished();
}

void MainWindow::on_stream12_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p12.sh");
    process.waitForFinished();
}

void MainWindow::on_actionAbout_triggered()
{
    About mAbout;
    mAbout.setModal(true);
    mAbout.exec();
}

void MainWindow::on_actionOpzioni_triggered()
{
    Opzioni mOpzioni;
    mOpzioni.setModal(true);
    mOpzioni.exec();
}

void MainWindow::on_down13_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d13.sh");
    process.waitForFinished();
}

void MainWindow::on_stream13_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p13.sh");
    process.waitForFinished();
}

void MainWindow::on_actionServizioPubblico_Online_triggered()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/official.sh");
    process.waitForFinished();
}
